@@ -72,7 +72,6 @@ struct oqsx_gen_ctx {
     OSSL_LIB_CTX *libctx;
     char *propq;
     char *oqs_name;
-    char *cmp_name;
     char *tls_name;
     int primitive;
     int selection;
@@ -591,7 +590,6 @@ static void *oqsx_gen_init(void *provctx, int selection, char *oqs_name,
 
     if ((gctx = OPENSSL_zalloc(sizeof(*gctx))) != NULL) {
         gctx->libctx = libctx;
-        gctx->cmp_name = NULL;
         gctx->oqs_name = OPENSSL_strdup(oqs_name);
         gctx->tls_name = OPENSSL_strdup(tls_name);
         gctx->primitive = primitive;
@@ -723,545 +721,528 @@ static void *rsa3072_mldsa44_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44,
                          "rsa3072_mldsa44", KEY_TYPE_HYB_SIG, 128, 2, 0);
 }
-static void *mldsa44_pss2048_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_44,
-                        "mldsa44_pss2048", KEY_TYPE_CMP_SIG, NULL, 112, 3, 0);
-}
-
-static void *mldsa44_pss2048_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44,
-                         "mldsa44_pss2048", KEY_TYPE_CMP_SIG, 112, 3, 0);
-}
-static void *mldsa44_rsa2048_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_44,
-                        "mldsa44_rsa2048", KEY_TYPE_CMP_SIG, NULL, 112, 4, 0);
-}
-
-static void *mldsa44_rsa2048_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44,
-                         "mldsa44_rsa2048", KEY_TYPE_CMP_SIG, 112, 4, 0);
-}
-static void *mldsa44_ed25519_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_44,
-                        "mldsa44_ed25519", KEY_TYPE_CMP_SIG, NULL, 128, 5, 0);
-}
-
-static void *mldsa44_ed25519_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44,
-                         "mldsa44_ed25519", KEY_TYPE_CMP_SIG, 128, 5, 0);
-}
-static void *mldsa44_p256_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_44,
-                        "mldsa44_p256", KEY_TYPE_CMP_SIG, NULL, 128, 6, 0);
-}
-
-static void *mldsa44_p256_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44,
-                         "mldsa44_p256", KEY_TYPE_CMP_SIG, 128, 6, 0);
-}
-static void *mldsa44_bp256_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_44,
-                        "mldsa44_bp256", KEY_TYPE_CMP_SIG, NULL, 256, 7, 0);
-}
-
-static void *mldsa44_bp256_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44,
-                         "mldsa44_bp256", KEY_TYPE_CMP_SIG, 256, 7, 0);
-}
 static void *mldsa65_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "mldsa65", KEY_TYPE_SIG, NULL, 192, 8, 0);
+                        "mldsa65", KEY_TYPE_SIG, NULL, 192, 3, 0);
 }
 
 static void *mldsa65_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65, "mldsa65",
-                         0, 192, 8, 0);
+                         0, 192, 3, 0);
 }
 static void *p384_mldsa65_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "p384_mldsa65", KEY_TYPE_HYB_SIG, NULL, 192, 9, 0);
+                        "p384_mldsa65", KEY_TYPE_HYB_SIG, NULL, 192, 4, 0);
 }
 
 static void *p384_mldsa65_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65,
-                         "p384_mldsa65", KEY_TYPE_HYB_SIG, 192, 9, 0);
-}
-static void *mldsa65_pss3072_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "mldsa65_pss3072", KEY_TYPE_CMP_SIG, NULL, 128, 10, 0);
-}
-
-static void *mldsa65_pss3072_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65,
-                         "mldsa65_pss3072", KEY_TYPE_CMP_SIG, 128, 10, 0);
-}
-static void *mldsa65_rsa3072_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "mldsa65_rsa3072", KEY_TYPE_CMP_SIG, NULL, 128, 11, 0);
-}
-
-static void *mldsa65_rsa3072_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65,
-                         "mldsa65_rsa3072", KEY_TYPE_CMP_SIG, 128, 11, 0);
-}
-static void *mldsa65_p256_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "mldsa65_p256", KEY_TYPE_CMP_SIG, NULL, 128, 12, 0);
-}
-
-static void *mldsa65_p256_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65,
-                         "mldsa65_p256", KEY_TYPE_CMP_SIG, 128, 12, 0);
-}
-static void *mldsa65_bp256_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "mldsa65_bp256", KEY_TYPE_CMP_SIG, NULL, 256, 13, 0);
-}
-
-static void *mldsa65_bp256_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65,
-                         "mldsa65_bp256", KEY_TYPE_CMP_SIG, 256, 13, 0);
-}
-static void *mldsa65_ed25519_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "mldsa65_ed25519", KEY_TYPE_CMP_SIG, NULL, 128, 14, 0);
-}
-
-static void *mldsa65_ed25519_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65,
-                         "mldsa65_ed25519", KEY_TYPE_CMP_SIG, 128, 14, 0);
+                         "p384_mldsa65", KEY_TYPE_HYB_SIG, 192, 4, 0);
 }
 static void *mldsa87_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_87,
-                        "mldsa87", KEY_TYPE_SIG, NULL, 256, 15, 0);
+                        "mldsa87", KEY_TYPE_SIG, NULL, 256, 5, 0);
 }
 
 static void *mldsa87_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_87, "mldsa87",
-                         0, 256, 15, 0);
+                         0, 256, 5, 0);
 }
 static void *p521_mldsa87_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_87,
-                        "p521_mldsa87", KEY_TYPE_HYB_SIG, NULL, 256, 16, 0);
+                        "p521_mldsa87", KEY_TYPE_HYB_SIG, NULL, 256, 6, 0);
 }
 
 static void *p521_mldsa87_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_87,
-                         "p521_mldsa87", KEY_TYPE_HYB_SIG, 256, 16, 0);
-}
-static void *mldsa87_p384_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_87,
-                        "mldsa87_p384", KEY_TYPE_CMP_SIG, NULL, 192, 17, 0);
-}
-
-static void *mldsa87_p384_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_87,
-                         "mldsa87_p384", KEY_TYPE_CMP_SIG, 192, 17, 0);
-}
-static void *mldsa87_bp384_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_87,
-                        "mldsa87_bp384", KEY_TYPE_CMP_SIG, NULL, 384, 18, 0);
-}
-
-static void *mldsa87_bp384_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_87,
-                         "mldsa87_bp384", KEY_TYPE_CMP_SIG, 384, 18, 0);
-}
-static void *mldsa87_ed448_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_87,
-                        "mldsa87_ed448", KEY_TYPE_CMP_SIG, NULL, 192, 19, 0);
-}
-
-static void *mldsa87_ed448_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_87,
-                         "mldsa87_ed448", KEY_TYPE_CMP_SIG, 192, 19, 0);
+                         "p521_mldsa87", KEY_TYPE_HYB_SIG, 256, 6, 0);
 }
 
 static void *falcon512_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_falcon_512,
-                        "falcon512", KEY_TYPE_SIG, NULL, 128, 20, 0);
+                        "falcon512", KEY_TYPE_SIG, NULL, 128, 7, 0);
 }
 
 static void *falcon512_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_512,
-                         "falcon512", 0, 128, 20, 0);
+                         "falcon512", 0, 128, 7, 0);
 }
 static void *p256_falcon512_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_falcon_512,
-                        "p256_falcon512", KEY_TYPE_HYB_SIG, NULL, 128, 21, 0);
+                        "p256_falcon512", KEY_TYPE_HYB_SIG, NULL, 128, 8, 0);
 }
 
 static void *p256_falcon512_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_512,
-                         "p256_falcon512", KEY_TYPE_HYB_SIG, 128, 21, 0);
+                         "p256_falcon512", KEY_TYPE_HYB_SIG, 128, 8, 0);
 }
 static void *rsa3072_falcon512_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_falcon_512,
-                        "rsa3072_falcon512", KEY_TYPE_HYB_SIG, NULL, 128, 22,
-                        0);
+                        "rsa3072_falcon512", KEY_TYPE_HYB_SIG, NULL, 128, 9, 0);
 }
 
 static void *rsa3072_falcon512_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_512,
-                         "rsa3072_falcon512", KEY_TYPE_HYB_SIG, 128, 22, 0);
+                         "rsa3072_falcon512", KEY_TYPE_HYB_SIG, 128, 9, 0);
 }
 static void *falconpadded512_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_falcon_padded_512, "falconpadded512",
-                        KEY_TYPE_SIG, NULL, 128, 23, 0);
+                        KEY_TYPE_SIG, NULL, 128, 10, 0);
 }
 
 static void *falconpadded512_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_padded_512,
-                         "falconpadded512", 0, 128, 23, 0);
+                         "falconpadded512", 0, 128, 10, 0);
 }
 static void *p256_falconpadded512_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_falcon_padded_512, "p256_falconpadded512",
-                        KEY_TYPE_HYB_SIG, NULL, 128, 24, 0);
+                        KEY_TYPE_HYB_SIG, NULL, 128, 11, 0);
 }
 
 static void *p256_falconpadded512_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_padded_512,
-                         "p256_falconpadded512", KEY_TYPE_HYB_SIG, 128, 24, 0);
+                         "p256_falconpadded512", KEY_TYPE_HYB_SIG, 128, 11, 0);
 }
 static void *rsa3072_falconpadded512_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_falcon_padded_512,
-        "rsa3072_falconpadded512", KEY_TYPE_HYB_SIG, NULL, 128, 25, 0);
+        "rsa3072_falconpadded512", KEY_TYPE_HYB_SIG, NULL, 128, 12, 0);
 }
 
 static void *rsa3072_falconpadded512_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_padded_512,
-                         "rsa3072_falconpadded512", KEY_TYPE_HYB_SIG, 128, 25,
+                         "rsa3072_falconpadded512", KEY_TYPE_HYB_SIG, 128, 12,
                          0);
 }
 static void *falcon1024_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_falcon_1024,
-                        "falcon1024", KEY_TYPE_SIG, NULL, 256, 26, 0);
+                        "falcon1024", KEY_TYPE_SIG, NULL, 256, 13, 0);
 }
 
 static void *falcon1024_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_1024,
-                         "falcon1024", 0, 256, 26, 0);
+                         "falcon1024", 0, 256, 13, 0);
 }
 static void *p521_falcon1024_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_falcon_1024,
-                        "p521_falcon1024", KEY_TYPE_HYB_SIG, NULL, 256, 27, 0);
+                        "p521_falcon1024", KEY_TYPE_HYB_SIG, NULL, 256, 14, 0);
 }
 
 static void *p521_falcon1024_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_1024,
-                         "p521_falcon1024", KEY_TYPE_HYB_SIG, 256, 27, 0);
+                         "p521_falcon1024", KEY_TYPE_HYB_SIG, 256, 14, 0);
 }
 static void *falconpadded1024_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_falcon_padded_1024, "falconpadded1024",
-                        KEY_TYPE_SIG, NULL, 256, 28, 0);
+                        KEY_TYPE_SIG, NULL, 256, 15, 0);
 }
 
 static void *falconpadded1024_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_padded_1024,
-                         "falconpadded1024", 0, 256, 28, 0);
+                         "falconpadded1024", 0, 256, 15, 0);
 }
 static void *p521_falconpadded1024_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_falcon_padded_1024, "p521_falconpadded1024",
-                        KEY_TYPE_HYB_SIG, NULL, 256, 29, 0);
+                        KEY_TYPE_HYB_SIG, NULL, 256, 16, 0);
 }
 
 static void *p521_falconpadded1024_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_padded_1024,
-                         "p521_falconpadded1024", KEY_TYPE_HYB_SIG, 256, 29, 0);
+                         "p521_falconpadded1024", KEY_TYPE_HYB_SIG, 256, 16, 0);
 }
 
 static void *sphincssha2128fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_128f_simple,
-        "sphincssha2128fsimple", KEY_TYPE_SIG, NULL, 128, 30, 0);
+        "sphincssha2128fsimple", KEY_TYPE_SIG, NULL, 128, 17, 0);
 }
 
 static void *sphincssha2128fsimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection,
                          OQS_SIG_alg_sphincs_sha2_128f_simple,
-                         "sphincssha2128fsimple", 0, 128, 30, 0);
+                         "sphincssha2128fsimple", 0, 128, 17, 0);
 }
 static void *p256_sphincssha2128fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_128f_simple,
-        "p256_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 31, 0);
+        "p256_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 18, 0);
 }
 
 static void *p256_sphincssha2128fsimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_sha2_128f_simple,
-        "p256_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, 128, 31, 0);
+        "p256_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, 128, 18, 0);
 }
 static void *rsa3072_sphincssha2128fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_128f_simple,
-        "rsa3072_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 32, 0);
+        "rsa3072_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 19, 0);
 }
 
 static void *rsa3072_sphincssha2128fsimple_gen_init(void *provctx,
                                                     int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_sha2_128f_simple,
-        "rsa3072_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, 128, 32, 0);
+        "rsa3072_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, 128, 19, 0);
 }
 static void *sphincssha2128ssimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_128s_simple,
-        "sphincssha2128ssimple", KEY_TYPE_SIG, NULL, 128, 33, 0);
+        "sphincssha2128ssimple", KEY_TYPE_SIG, NULL, 128, 20, 0);
 }
 
 static void *sphincssha2128ssimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection,
                          OQS_SIG_alg_sphincs_sha2_128s_simple,
-                         "sphincssha2128ssimple", 0, 128, 33, 0);
+                         "sphincssha2128ssimple", 0, 128, 20, 0);
 }
 static void *p256_sphincssha2128ssimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_128s_simple,
-        "p256_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, NULL, 128, 34, 0);
+        "p256_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, NULL, 128, 21, 0);
 }
 
 static void *p256_sphincssha2128ssimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_sha2_128s_simple,
-        "p256_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, 128, 34, 0);
+        "p256_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, 128, 21, 0);
 }
 static void *rsa3072_sphincssha2128ssimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_128s_simple,
-        "rsa3072_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, NULL, 128, 35, 0);
+        "rsa3072_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, NULL, 128, 22, 0);
 }
 
 static void *rsa3072_sphincssha2128ssimple_gen_init(void *provctx,
                                                     int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_sha2_128s_simple,
-        "rsa3072_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, 128, 35, 0);
+        "rsa3072_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, 128, 22, 0);
 }
 static void *sphincssha2192fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_192f_simple,
-        "sphincssha2192fsimple", KEY_TYPE_SIG, NULL, 192, 36, 0);
+        "sphincssha2192fsimple", KEY_TYPE_SIG, NULL, 192, 23, 0);
 }
 
 static void *sphincssha2192fsimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection,
                          OQS_SIG_alg_sphincs_sha2_192f_simple,
-                         "sphincssha2192fsimple", 0, 192, 36, 0);
+                         "sphincssha2192fsimple", 0, 192, 23, 0);
 }
 static void *p384_sphincssha2192fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_192f_simple,
-        "p384_sphincssha2192fsimple", KEY_TYPE_HYB_SIG, NULL, 192, 37, 0);
+        "p384_sphincssha2192fsimple", KEY_TYPE_HYB_SIG, NULL, 192, 24, 0);
 }
 
 static void *p384_sphincssha2192fsimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_sha2_192f_simple,
-        "p384_sphincssha2192fsimple", KEY_TYPE_HYB_SIG, 192, 37, 0);
+        "p384_sphincssha2192fsimple", KEY_TYPE_HYB_SIG, 192, 24, 0);
 }
 
 static void *sphincsshake128fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_shake_128f_simple,
-        "sphincsshake128fsimple", KEY_TYPE_SIG, NULL, 128, 38, 0);
+        "sphincsshake128fsimple", KEY_TYPE_SIG, NULL, 128, 25, 0);
 }
 
 static void *sphincsshake128fsimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection,
                          OQS_SIG_alg_sphincs_shake_128f_simple,
-                         "sphincsshake128fsimple", 0, 128, 38, 0);
+                         "sphincsshake128fsimple", 0, 128, 25, 0);
 }
 static void *p256_sphincsshake128fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_shake_128f_simple,
-        "p256_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 39, 0);
+        "p256_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 26, 0);
 }
 
 static void *p256_sphincsshake128fsimple_gen_init(void *provctx,
                                                   int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_shake_128f_simple,
-        "p256_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, 128, 39, 0);
+        "p256_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, 128, 26, 0);
 }
 static void *rsa3072_sphincsshake128fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_shake_128f_simple,
-        "rsa3072_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 40, 0);
+        "rsa3072_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 27, 0);
 }
 
 static void *rsa3072_sphincsshake128fsimple_gen_init(void *provctx,
                                                      int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_shake_128f_simple,
-        "rsa3072_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, 128, 40, 0);
+        "rsa3072_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, 128, 27, 0);
 }
 
 static void *mayo1_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_1,
-                        "mayo1", KEY_TYPE_SIG, NULL, 128, 41, 0);
+                        "mayo1", KEY_TYPE_SIG, NULL, 128, 28, 0);
 }
 
 static void *mayo1_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_1, "mayo1", 0,
-                         128, 41, 0);
+                         128, 28, 0);
 }
 static void *p256_mayo1_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_1,
-                        "p256_mayo1", KEY_TYPE_HYB_SIG, NULL, 128, 42, 0);
+                        "p256_mayo1", KEY_TYPE_HYB_SIG, NULL, 128, 29, 0);
 }
 
 static void *p256_mayo1_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_1, "p256_mayo1",
-                         KEY_TYPE_HYB_SIG, 128, 42, 0);
+                         KEY_TYPE_HYB_SIG, 128, 29, 0);
 }
 static void *mayo2_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_2,
-                        "mayo2", KEY_TYPE_SIG, NULL, 128, 43, 0);
+                        "mayo2", KEY_TYPE_SIG, NULL, 128, 30, 0);
 }
 
 static void *mayo2_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_2, "mayo2", 0,
-                         128, 43, 0);
+                         128, 30, 0);
 }
 static void *p256_mayo2_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_2,
-                        "p256_mayo2", KEY_TYPE_HYB_SIG, NULL, 128, 44, 0);
+                        "p256_mayo2", KEY_TYPE_HYB_SIG, NULL, 128, 31, 0);
 }
 
 static void *p256_mayo2_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_2, "p256_mayo2",
-                         KEY_TYPE_HYB_SIG, 128, 44, 0);
+                         KEY_TYPE_HYB_SIG, 128, 31, 0);
 }
 static void *mayo3_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_3,
-                        "mayo3", KEY_TYPE_SIG, NULL, 192, 45, 0);
+                        "mayo3", KEY_TYPE_SIG, NULL, 192, 32, 0);
 }
 
 static void *mayo3_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_3, "mayo3", 0,
-                         192, 45, 0);
+                         192, 32, 0);
 }
 static void *p384_mayo3_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_3,
-                        "p384_mayo3", KEY_TYPE_HYB_SIG, NULL, 192, 46, 0);
+                        "p384_mayo3", KEY_TYPE_HYB_SIG, NULL, 192, 33, 0);
 }
 
 static void *p384_mayo3_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_3, "p384_mayo3",
-                         KEY_TYPE_HYB_SIG, 192, 46, 0);
+                         KEY_TYPE_HYB_SIG, 192, 33, 0);
 }
 static void *mayo5_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_5,
-                        "mayo5", KEY_TYPE_SIG, NULL, 256, 47, 0);
+                        "mayo5", KEY_TYPE_SIG, NULL, 256, 34, 0);
 }
 
 static void *mayo5_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_5, "mayo5", 0,
-                         256, 47, 0);
+                         256, 34, 0);
 }
 static void *p521_mayo5_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_5,
-                        "p521_mayo5", KEY_TYPE_HYB_SIG, NULL, 256, 48, 0);
+                        "p521_mayo5", KEY_TYPE_HYB_SIG, NULL, 256, 35, 0);
 }
 
 static void *p521_mayo5_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_5, "p521_mayo5",
-                         KEY_TYPE_HYB_SIG, 256, 48, 0);
+                         KEY_TYPE_HYB_SIG, 256, 35, 0);
 }
 
 static void *CROSSrsdp128balanced_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_cross_rsdp_128_balanced,
-                        "CROSSrsdp128balanced", KEY_TYPE_SIG, NULL, 128, 49, 0);
+                        "CROSSrsdp128balanced", KEY_TYPE_SIG, NULL, 128, 36, 0);
 }
 
 static void *CROSSrsdp128balanced_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection,
                          OQS_SIG_alg_cross_rsdp_128_balanced,
-                         "CROSSrsdp128balanced", 0, 128, 49, 0);
+                         "CROSSrsdp128balanced", 0, 128, 36, 0);
 }
 
 static void *OV_Is_pkc_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_uov_ov_Is_pkc,
-                        "OV_Is_pkc", KEY_TYPE_SIG, NULL, 128, 50, 0);
+                        "OV_Is_pkc", KEY_TYPE_SIG, NULL, 128, 37, 0);
 }
 
 static void *OV_Is_pkc_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Is_pkc,
-                         "OV_Is_pkc", 0, 128, 50, 0);
+                         "OV_Is_pkc", 0, 128, 37, 0);
 }
 static void *p256_OV_Is_pkc_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_uov_ov_Is_pkc,
-                        "p256_OV_Is_pkc", KEY_TYPE_HYB_SIG, NULL, 128, 51, 0);
+                        "p256_OV_Is_pkc", KEY_TYPE_HYB_SIG, NULL, 128, 38, 0);
 }
 
 static void *p256_OV_Is_pkc_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Is_pkc,
-                         "p256_OV_Is_pkc", KEY_TYPE_HYB_SIG, 128, 51, 0);
+                         "p256_OV_Is_pkc", KEY_TYPE_HYB_SIG, 128, 38, 0);
 }
 static void *OV_Ip_pkc_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_uov_ov_Ip_pkc,
-                        "OV_Ip_pkc", KEY_TYPE_SIG, NULL, 128, 52, 0);
+                        "OV_Ip_pkc", KEY_TYPE_SIG, NULL, 128, 39, 0);
 }
 
 static void *OV_Ip_pkc_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Ip_pkc,
-                         "OV_Ip_pkc", 0, 128, 52, 0);
+                         "OV_Ip_pkc", 0, 128, 39, 0);
 }
 static void *p256_OV_Ip_pkc_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_uov_ov_Ip_pkc,
-                        "p256_OV_Ip_pkc", KEY_TYPE_HYB_SIG, NULL, 128, 53, 0);
+                        "p256_OV_Ip_pkc", KEY_TYPE_HYB_SIG, NULL, 128, 40, 0);
 }
 
 static void *p256_OV_Ip_pkc_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Ip_pkc,
-                         "p256_OV_Ip_pkc", KEY_TYPE_HYB_SIG, 128, 53, 0);
+                         "p256_OV_Ip_pkc", KEY_TYPE_HYB_SIG, 128, 40, 0);
 }
 static void *OV_Is_pkc_skc_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_uov_ov_Is_pkc_skc, "OV_Is_pkc_skc",
-                        KEY_TYPE_SIG, NULL, 128, 54, 0);
+                        KEY_TYPE_SIG, NULL, 128, 41, 0);
 }
 
 static void *OV_Is_pkc_skc_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Is_pkc_skc,
-                         "OV_Is_pkc_skc", 0, 128, 54, 0);
+                         "OV_Is_pkc_skc", 0, 128, 41, 0);
 }
 static void *p256_OV_Is_pkc_skc_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_uov_ov_Is_pkc_skc, "p256_OV_Is_pkc_skc",
-                        KEY_TYPE_HYB_SIG, NULL, 128, 55, 0);
+                        KEY_TYPE_HYB_SIG, NULL, 128, 42, 0);
 }
 
 static void *p256_OV_Is_pkc_skc_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Is_pkc_skc,
-                         "p256_OV_Is_pkc_skc", KEY_TYPE_HYB_SIG, 128, 55, 0);
+                         "p256_OV_Is_pkc_skc", KEY_TYPE_HYB_SIG, 128, 42, 0);
 }
 static void *OV_Ip_pkc_skc_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_uov_ov_Ip_pkc_skc, "OV_Ip_pkc_skc",
-                        KEY_TYPE_SIG, NULL, 128, 56, 0);
+                        KEY_TYPE_SIG, NULL, 128, 43, 0);
 }
 
 static void *OV_Ip_pkc_skc_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Ip_pkc_skc,
-                         "OV_Ip_pkc_skc", 0, 128, 56, 0);
+                         "OV_Ip_pkc_skc", 0, 128, 43, 0);
 }
 static void *p256_OV_Ip_pkc_skc_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_uov_ov_Ip_pkc_skc, "p256_OV_Ip_pkc_skc",
-                        KEY_TYPE_HYB_SIG, NULL, 128, 57, 0);
+                        KEY_TYPE_HYB_SIG, NULL, 128, 44, 0);
 }
 
 static void *p256_OV_Ip_pkc_skc_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Ip_pkc_skc,
-                         "p256_OV_Ip_pkc_skc", KEY_TYPE_HYB_SIG, 128, 57, 0);
+                         "p256_OV_Ip_pkc_skc", KEY_TYPE_HYB_SIG, 128, 44, 0);
+}
+
+static void *snova2454_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_snova_SNOVA_24_5_4, "snova2454",
+                        KEY_TYPE_SIG, NULL, 128, 45, 0);
+}
+
+static void *snova2454_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_snova_SNOVA_24_5_4,
+                         "snova2454", 0, 128, 45, 0);
+}
+static void *p256_snova2454_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_snova_SNOVA_24_5_4, "p256_snova2454",
+                        KEY_TYPE_HYB_SIG, NULL, 128, 46, 0);
+}
+
+static void *p256_snova2454_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_snova_SNOVA_24_5_4,
+                         "p256_snova2454", KEY_TYPE_HYB_SIG, 128, 46, 0);
+}
+static void *snova2454esk_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_snova_SNOVA_24_5_4_esk, "snova2454esk",
+                        KEY_TYPE_SIG, NULL, 128, 47, 0);
+}
+
+static void *snova2454esk_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_snova_SNOVA_24_5_4_esk,
+                         "snova2454esk", 0, 128, 47, 0);
+}
+static void *p256_snova2454esk_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_snova_SNOVA_24_5_4_esk, "p256_snova2454esk",
+                        KEY_TYPE_HYB_SIG, NULL, 128, 48, 0);
+}
+
+static void *p256_snova2454esk_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_snova_SNOVA_24_5_4_esk,
+                         "p256_snova2454esk", KEY_TYPE_HYB_SIG, 128, 48, 0);
+}
+static void *snova37172_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_snova_SNOVA_37_17_2, "snova37172",
+                        KEY_TYPE_SIG, NULL, 128, 49, 0);
+}
+
+static void *snova37172_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_snova_SNOVA_37_17_2,
+                         "snova37172", 0, 128, 49, 0);
+}
+static void *p256_snova37172_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_snova_SNOVA_37_17_2, "p256_snova37172",
+                        KEY_TYPE_HYB_SIG, NULL, 128, 50, 0);
+}
+
+static void *p256_snova37172_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_snova_SNOVA_37_17_2,
+                         "p256_snova37172", KEY_TYPE_HYB_SIG, 128, 50, 0);
+}
+static void *snova2455_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_snova_SNOVA_24_5_5, "snova2455",
+                        KEY_TYPE_SIG, NULL, 192, 51, 0);
+}
+
+static void *snova2455_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_snova_SNOVA_24_5_5,
+                         "snova2455", 0, 192, 51, 0);
+}
+static void *p384_snova2455_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_snova_SNOVA_24_5_5, "p384_snova2455",
+                        KEY_TYPE_HYB_SIG, NULL, 192, 52, 0);
+}
+
+static void *p384_snova2455_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_snova_SNOVA_24_5_5,
+                         "p384_snova2455", KEY_TYPE_HYB_SIG, 192, 52, 0);
+}
+static void *snova2965_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_snova_SNOVA_29_6_5, "snova2965",
+                        KEY_TYPE_SIG, NULL, 256, 53, 0);
+}
+
+static void *snova2965_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_snova_SNOVA_29_6_5,
+                         "snova2965", 0, 256, 53, 0);
+}
+static void *p521_snova2965_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_snova_SNOVA_29_6_5, "p521_snova2965",
+                        KEY_TYPE_HYB_SIG, NULL, 256, 54, 0);
+}
+
+static void *p521_snova2965_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_snova_SNOVA_29_6_5,
+                         "p521_snova2965", KEY_TYPE_HYB_SIG, 256, 54, 0);
 }
 
 ///// OQS_TEMPLATE_FRAGMENT_KEYMGMT_CONSTRUCTORS_END
@@ -1411,23 +1392,10 @@ static void *p256_OV_Ip_pkc_skc_gen_init(void *provctx, int selection) {
 MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa44)
 MAKE_SIG_KEYMGMT_FUNCTIONS(p256_mldsa44)
 MAKE_SIG_KEYMGMT_FUNCTIONS(rsa3072_mldsa44)
-MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa44_pss2048)
-MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa44_rsa2048)
-MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa44_ed25519)
-MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa44_p256)
-MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa44_bp256)
 MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa65)
 MAKE_SIG_KEYMGMT_FUNCTIONS(p384_mldsa65)
-MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa65_pss3072)
-MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa65_rsa3072)
-MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa65_p256)
-MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa65_bp256)
-MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa65_ed25519)
 MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa87)
 MAKE_SIG_KEYMGMT_FUNCTIONS(p521_mldsa87)
-MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa87_p384)
-MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa87_bp384)
-MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa87_ed448)
 MAKE_SIG_KEYMGMT_FUNCTIONS(falcon512)
 MAKE_SIG_KEYMGMT_FUNCTIONS(p256_falcon512)
 MAKE_SIG_KEYMGMT_FUNCTIONS(rsa3072_falcon512)
@@ -1466,6 +1434,16 @@ MAKE_SIG_KEYMGMT_FUNCTIONS(OV_Is_pkc_skc)
 MAKE_SIG_KEYMGMT_FUNCTIONS(p256_OV_Is_pkc_skc)
 MAKE_SIG_KEYMGMT_FUNCTIONS(OV_Ip_pkc_skc)
 MAKE_SIG_KEYMGMT_FUNCTIONS(p256_OV_Ip_pkc_skc)
+MAKE_SIG_KEYMGMT_FUNCTIONS(snova2454)
+MAKE_SIG_KEYMGMT_FUNCTIONS(p256_snova2454)
+MAKE_SIG_KEYMGMT_FUNCTIONS(snova2454esk)
+MAKE_SIG_KEYMGMT_FUNCTIONS(p256_snova2454esk)
+MAKE_SIG_KEYMGMT_FUNCTIONS(snova37172)
+MAKE_SIG_KEYMGMT_FUNCTIONS(p256_snova37172)
+MAKE_SIG_KEYMGMT_FUNCTIONS(snova2455)
+MAKE_SIG_KEYMGMT_FUNCTIONS(p384_snova2455)
+MAKE_SIG_KEYMGMT_FUNCTIONS(snova2965)
+MAKE_SIG_KEYMGMT_FUNCTIONS(p521_snova2965)
 
 MAKE_KEM_KEYMGMT_FUNCTIONS(frodo640aes, OQS_KEM_alg_frodokem_640_aes, 128)
 
