@@ -13,88 +13,6 @@
 #include "oqs_prov.h"
 #include "test_common.h"
 
-///// OQS_TEMPLATE_FRAGMENT_HYBRID_SIG_ALGS_START
-
-/** \brief List of hybrid signature algorithms. */
-const char *kHybridSignatureAlgorithms[] = {
-    "p256_dilithium2",
-    "rsa3072_dilithium2",
-    "p384_dilithium3",
-    "p521_dilithium5",
-    "p256_mldsa44",
-    "rsa3072_mldsa44",
-    "p384_mldsa65",
-    "p521_mldsa87",
-    "p256_falcon512",
-    "rsa3072_falcon512",
-    "p256_falconpadded512",
-    "rsa3072_falconpadded512",
-    "p521_falcon1024",
-    "p521_falconpadded1024",
-    "p256_sphincssha2128fsimple",
-    "rsa3072_sphincssha2128fsimple",
-    "p256_sphincssha2128ssimple",
-    "rsa3072_sphincssha2128ssimple",
-    "p384_sphincssha2192fsimple",
-    "p256_sphincsshake128fsimple",
-    "rsa3072_sphincsshake128fsimple",
-    "p256_mayo1",
-    "p256_mayo2",
-    "p384_mayo3",
-    "p521_mayo5",
-    NULL,
-};
-///// OQS_TEMPLATE_FRAGMENT_HYBRID_SIG_ALGS_END
-
-///// OQS_TEMPLATE_FRAGMENT_HYBRID_KEM_ALGS_START
-
-/** \brief List of hybrid KEMs. */
-const char *kHybridKEMAlgorithms[] = {
-    "p256_frodo640aes",     "x25519_frodo640aes", "p256_frodo640shake",
-    "x25519_frodo640shake", "p384_frodo976aes",   "x448_frodo976aes",
-    "p384_frodo976shake",   "x448_frodo976shake", "p521_frodo1344aes",
-    "p521_frodo1344shake",  "p256_kyber512",      "x25519_kyber512",
-    "p384_kyber768",        "x448_kyber768",      "x25519_kyber768",
-    "p256_kyber768",        "p521_kyber1024",     "p256_mlkem512",
-    "x25519_mlkem512",      "p384_mlkem768",      "x448_mlkem768",
-    "X25519MLKEM768",       "SecP256r1MLKEM768",  "p521_mlkem1024",
-    "p384_mlkem1024",       "p256_bikel1",        "x25519_bikel1",
-    "p384_bikel3",          "x448_bikel3",        "p521_bikel5",
-    "p256_hqc128",          "x25519_hqc128",      "p384_hqc192",
-    "x448_hqc192",          "p521_hqc256",        NULL,
-}; ///// OQS_TEMPLATE_FRAGMENT_HYBRID_KEM_ALGS_END
-
-/** \brief Indicates if a string is in a given list of strings.
- *
- * \param list List of strings.
- * \param s String to test.
- *
- * \return 1 if `s` is in `list`, else 0. */
-static int is_string_in_list(const char **list, const char *s) {
-    for (; *list != NULL && strcmp(*list, s) != 0; ++list)
-        ;
-    if (*list != NULL) {
-        return 1;
-    }
-    return 0;
-}
-
-/** \brief Indicates if a signature algorithm is hybrid or not.
- *
- * \param alg Algorithm name.
- *
- * \returns 1 if hybrid, else 0. */
-#define is_signature_algorithm_hybrid(_alg_)                                   \
-    is_string_in_list(kHybridSignatureAlgorithms, (_alg_))
-
-/** \brief Indicates if an kem algorithm is hybrid or not.
- *
- * \param alg Algorithm name.
- *
- * \returns 1 if hybrid, else 0. */
-#define is_kem_algorithm_hybrid(_alg_)                                         \
-    is_string_in_list(kHybridKEMAlgorithms, (_alg_))
-
 /** \brief A pair of keys. */
 struct KeyPair {
     /** \brief The public key. */
@@ -145,7 +63,7 @@ static OSSL_LIB_CTX *init_openssl(void) {
 static EVP_PKEY_CTX *init_EVP_PKEY_CTX(OSSL_LIB_CTX *libctx, const char *alg) {
     EVP_PKEY_CTX *ctx;
 
-    if (!(ctx = EVP_PKEY_CTX_new_from_name(libctx, alg, NULL))) {
+    if (!(ctx = EVP_PKEY_CTX_new_from_name(libctx, alg, OQSPROV_PROPQ))) {
         fprintf(stderr,
                 cRED "`EVP_PKEY_CTX_new_from_name` failed with algorithm %s: ",
                 alg);
@@ -202,52 +120,6 @@ static EVP_PKEY *generate_private_key(EVP_PKEY_CTX *ctx) {
     return private_key;
 }
 
-/** \brief Extracts an octet string from a parameter of an EVP_PKEY.
- *
- * \param key The EVP_PKEY;
- * \param param_name Name of the parameter.
- * \param[out] buf Out buffer.
- * \param[out] buf_len Size of out buffer.
- *
- * \returns 0 on success. */
-static int get_param_octet_string(const EVP_PKEY *key, const char *param_name,
-                                  uint8_t **buf, size_t *buf_len) {
-    *buf = NULL;
-    *buf_len = 0;
-    int ret = -1;
-
-    if (EVP_PKEY_get_octet_string_param(key, param_name, NULL, 0, buf_len) !=
-        1) {
-        fprintf(stderr,
-                cRED
-                "`EVP_PKEY_get_octet_string_param` failed with param `%s`: ",
-                param_name);
-        ERR_print_errors_fp(stderr);
-        fputs(cNORM "\n", stderr);
-        goto out;
-    }
-    if (!(*buf = malloc(*buf_len))) {
-        fprintf(stderr, "failed to allocate %#zx byte(s)\n", *buf_len);
-        goto out;
-    }
-    if (EVP_PKEY_get_octet_string_param(key, param_name, *buf, *buf_len,
-                                        buf_len) != 1) {
-        fprintf(stderr,
-                cRED
-                "`EVP_PKEY_get_octet_string_param` failed with param `%s`: ",
-                param_name);
-        ERR_print_errors_fp(stderr);
-        fputs(cNORM "\n", stderr);
-        free(*buf);
-        *buf = NULL;
-    } else {
-        ret = 0;
-    }
-
-out:
-    return ret;
-}
-
 /** \brief Extracts the classical keys from an hybrid key.
  *
  * \param private_key The private key.
@@ -610,4 +482,4 @@ free_libctx:
 
 end:
     return ret;
-}
\ No newline at end of file
+}
